/*
 * Java-Gnome Bindings Library
 *
 * * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome Team Members:
 *   Jean Van Wyk <jeanvanwyk@iname.com>
 *   Jeffrey S. Morgan <jeffrey.morgan@bristolwest.com>
 *   Dan Bornstein <danfuzz@milk.com>
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk.event;

import org.gnu.glib.EventType;

/**
 * An event represeting action by a {@link org.gnu.gtk.CellRendererToggle}
 * widget.
 * 
 * @see CellRendererToggleListener
 * @see org.gnu.gtk.CellRendererToggle
 */
public class CellRendererToggleEvent extends GtkEvent {

    public static class Type extends EventType {
        private Type(int id, String name) {
            super(id, name);
        }

        /**
         * This event indicates that the menu item has been toggled.
         */
        public static final Type TOGGLED = new Type(1, "TOGGLED");
    }

    protected String path;

    /**
     * Creates a new event. This is used internally by java-gnome. Users only
     * have to deal with listeners.
     */
    public CellRendererToggleEvent(Object source, String path) {
        super(source, Type.TOGGLED);
        this.path = path;
    }

    /**
     * Returns the TreeIter index of which the text has been changed.
     * 
     * @return the TreeIter index
     */
    public String getPath() {
        return this.path;
    }

}
